Interior Point Controls — ecyglpki 0.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.2.0 documentation »

# Interior Point Controls

class `ecyglpki.` `IPointControls`

  The interior point solver control parameter object

      >>> r = IPointControls()

  `msg_lev`

    The message level, a `str`

    The possible values are

    - `'no'`: no output
    - `'warnerror'`: warnings and errors only
    - `'normal'`: normal output
    - `'full'`: normal output and informational messages

        >>> r.msg_lev  # the GLPK default
        'full'
        >>> r.msg_lev = 'no'
        >>> r.msg_lev
        'no'

  `ord_alg`

    The ordering algorithm used prior to Cholesky factorization, a `str`

    The possible values are

    - `'orig'`: normal (original)
    - `'qmd'`: quotient minimum degree
    - `'amd'`: approximate minimum degree
    - `'symamd'`: approximate minimum degree for symmetric matrices

        >>> r.ord_alg  # the GLPK default
        'amd'
        >>> r.ord_alg = 'qmd'
        >>> r.ord_alg
        'qmd'

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.2.0 documentation »